@@ -407,9 +407,6 @@ func (c *Config) ModifySchema(s *schema.Schema) error {
 	for _, l := range c.Labels {
 		s.Labels = s.Labels.Merge(l)
 	}
-	if err := detectCardinality(s); err != nil {
-		return err
-	}
 	if err := detectPKFK(s); err != nil {
 		return err
 	}
@@ -506,18 +503,32 @@ func (c *Config) ModifySchema(s *schema.Schema) error {
 			return fmt.Errorf("viewpoint '%s' has unknown label '%s'", v.Name, l)
 		}
 	}
+	for vi, v := range s.Viewpoints {
+		// Add viewpoints to table
+
+		for _, t := range v.Tables {
+			println(v.Name, t)
+			table, err := s.FindTableByName(t)
+			if err != nil {
+				return err
+			}
+			table.Viewpoints = append(table.Viewpoints, &schema.TableViewpoint{
+				Index: vi,
+				Name:  v.Name,
+				Desc:  v.Desc,
+			})
+		}
+	}
 
 	return nil
 }
 
 // MergeAdditionalData merge relations: comments: to schema.Schema
 func (c *Config) MergeAdditionalData(s *schema.Schema) error {
-	err := mergeAdditionalRelations(s, c.Relations)
-	if err != nil {
+	if err := mergeAdditionalRelations(s, c.Relations); err != nil {
 		return err
 	}
-	err = mergeAdditionalComments(s, c.Comments)
-	if err != nil {
+	if err := mergeAdditionalComments(s, c.Comments); err != nil {
 		return err
 	}
 	return nil
@@ -539,47 +550,6 @@ func (c *Config) mergeDictFromSchema(s *schema.Schema) {
 	}
 }
 
-func excludeTableFromSchema(name string, s *schema.Schema) error {
-	// Tables
-	tables := []*schema.Table{}
-	for _, t := range s.Tables {
-		if t.Name != name {
-			tables = append(tables, t)
-		}
-		for _, c := range t.Columns {
-			// ChildRelations
-			childRelations := []*schema.Relation{}
-			for _, r := range c.ChildRelations {
-				if r.Table.Name != name && r.ParentTable.Name != name {
-					childRelations = append(childRelations, r)
-				}
-			}
-			c.ChildRelations = childRelations
-
-			// ParentRelations
-			parentRelations := []*schema.Relation{}
-			for _, r := range c.ParentRelations {
-				if r.Table.Name != name && r.ParentTable.Name != name {
-					parentRelations = append(parentRelations, r)
-				}
-			}
-			c.ParentRelations = parentRelations
-		}
-	}
-	s.Tables = tables
-
-	// Relations
-	relations := []*schema.Relation{}
-	for _, r := range s.Relations {
-		if r.Table.Name != name && r.ParentTable.Name != name {
-			relations = append(relations, r)
-		}
-	}
-	s.Relations = relations
-
-	return nil
-}
-
 // MaskedDSN return DSN mask password
 func (c *Config) MaskedDSN() (string, error) {
 	u, err := url.Parse(c.DSN.URL)
@@ -643,15 +613,24 @@ func (c *Config) detectShowColumnsForER(s *schema.Schema) error {
 
 func mergeAdditionalRelations(s *schema.Schema, relations []AdditionalRelation) error {
 	for _, r := range relations {
+		c, err := schema.ToCardinality(r.Cardinality)
+		if err != nil {
+			return errors.Wrap(err, "failed to add relation")
+		}
+		pc, err := schema.ToCardinality(r.ParentCardinality)
+		if err != nil {
+			return errors.Wrap(err, "failed to add relation")
+		}
 		relation := &schema.Relation{
-			Virtual: true,
+			Cardinality:       c,
+			ParentCardinality: pc,
+			Virtual:           true,
 		}
 		if r.Def != "" {
 			relation.Def = r.Def
 		} else {
 			relation.Def = "Additional Relation"
 		}
-		var err error
 		relation.Table, err = s.FindTableByName(r.Table)
 		if err != nil {
 			return errors.Wrap(err, "failed to add relation")
@@ -808,8 +787,9 @@ func matchLength(s []string, e string) (int, bool) {
 	return 0, false
 }
 
+// detectCardinality detects the cardinality of the relations
+// This function should be applied to the completed schema
 func detectCardinality(s *schema.Schema) error {
-	// This function should be applied to the completed schema
 	for _, r := range s.Relations {
 		// child
 		if r.Cardinality == schema.UnknownCardinality {
@@ -841,7 +821,7 @@ func detectCardinality(s *schema.Schema) error {
 
 		// parent
 		if r.ParentCardinality == schema.UnknownCardinality {
-			// whether the child colums are nullable or not.
+			// whether the child columns are nullable or not.
 			nullable := true
 			for _, c := range r.Columns {
 				if !c.Nullable {
@@ -884,17 +864,6 @@ func detectPKFK(s *schema.Schema) error {
 	return nil
 }
 
-func matchLabels(il []string, l schema.Labels) bool {
-	for _, ll := range l {
-		for _, ill := range il {
-			if wildcard.MatchSimple(ill, ll.Name) {
-				return true
-			}
-		}
-	}
-	return false
-}
-
 func match(s []string, e string) bool {
 	_, m := matchLength(s, e)
 	return m
