@@ -131,19 +131,26 @@ type Column struct {
 	HideForER       bool            `json:"-"`
 }
 
+type TableViewpoint struct {
+	Index int    `json:"index"`
+	Name  string `json:"name"`
+	Desc  string `json:"desc"`
+}
+
 // Table is the struct for database table
 type Table struct {
-	Name             string        `json:"name"`
-	Type             string        `json:"type"`
-	Comment          string        `json:"comment"`
-	Columns          []*Column     `json:"columns"`
-	Indexes          []*Index      `json:"indexes"`
-	Constraints      []*Constraint `json:"constraints"`
-	Triggers         []*Trigger    `json:"triggers"`
-	Def              string        `json:"def"`
-	Labels           Labels        `json:"labels,omitempty"`
-	ReferencedTables []*Table      `json:"referenced_tables,omitempty" yaml:"referencedTables,omitempty"`
-	External         bool          `json:"-"` // Table external to the schema
+	Name             string            `json:"name"`
+	Type             string            `json:"type"`
+	Comment          string            `json:"comment"`
+	Columns          []*Column         `json:"columns"`
+	Viewpoints       []*TableViewpoint `json:"viewpoints"`
+	Indexes          []*Index          `json:"indexes"`
+	Constraints      []*Constraint     `json:"constraints"`
+	Triggers         []*Trigger        `json:"triggers"`
+	Def              string            `json:"def"`
+	Labels           Labels            `json:"labels,omitempty"`
+	ReferencedTables []*Table          `json:"referenced_tables,omitempty" yaml:"referencedTables,omitempty"`
+	External         bool              `json:"-"` // Table external to the schema
 }
 
 // Relation is the struct for table relation
@@ -216,7 +223,7 @@ func (s *Schema) FindTableByName(name string) (*Table, error) {
 	return nil, errors.Errorf("not found table '%s'", name)
 }
 
-// FindRelation find relation by columns and parent colums
+// FindRelation find relation by columns and parent columns
 func (s *Schema) FindRelation(cs, pcs []*Column) (*Relation, error) {
 L:
 	for _, r := range s.Relations {
@@ -290,7 +297,10 @@ func (s *Schema) Sort() error {
 		return s.Relations[i].Table.Name < s.Relations[j].Table.Name
 	})
 	sort.SliceStable(s.Functions, func(i, j int) bool {
-		return s.Functions[i].Name < s.Functions[j].Name
+		if s.Functions[i].Name != s.Functions[j].Name {
+			return s.Functions[i].Name < s.Functions[j].Name
+		}
+		return s.Functions[i].Arguments < s.Functions[j].Arguments
 	})
 	sort.SliceStable(s.Viewpoints, func(i, j int) bool {
 		return s.Viewpoints[i].Name < s.Viewpoints[j].Name
